package net.t2code.alias.Spigot.config.config;

import net.t2code.alias.Spigot.Main;
import net.t2code.alias.Spigot.enums.Confirm;
import net.t2code.alias.util.Util;
import net.t2code.t2codelib.SPIGOT.api.items.T2C_ItemVersion;
import net.t2code.t2codelib.SPIGOT.api.yaml.T2C_ConfigWriter;
import net.t2code.t2codelib.util.T2C_ConfigItem;
import net.t2code.t2codelib.util.T2C_LanguageEnum;


import java.io.File;
import java.util.HashMap;
import java.util.List;

public class Config {

    public enum VALUES implements T2C_ConfigItem {
        language("plugin.language", "english", true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("In this option you can set the language of the plugin."));
                }}),

        updateCheckOnJoin("plugin.updateCheck.onJoin", true, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("In this option you can set if players with the permission 't2c.alias.updatemsg' will get an update message on join when an update for the plugin is available."));
                }}),

        updateCheckSeePreReleaseUpdates("plugin.updateCheck.seePreReleaseUpdates", true, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("In this option you can set whether you want to receive and display beta and snapshot versions in the update check."));
                }}),

        updateCheckTimeInterval("plugin.updateCheck.timeInterval", 60, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("In this option you can set the time interval in minutes in which updates should be checked."));
                }}),

        buyMessage("buy.message", true, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("With this option you can set whether a confirmation should be sent after the payment for an alias for which you have to pay."));
                }}),

        buyCurrency("buy.currency", "$", true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("With this option you set the currency."));
                }}),

        buyConfirmDefault("buy.confirm.use", Confirm.COMMAND, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can choose which confirmation method you want to use. (COMMAND, CHAT, GUI)"));
                }}),

        buyConfirmGuiFillItemDesc("buy.confirm.gui.fillItem", null, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of(" ", "!! You can change the GUI name and the button texts in the language file !!", " "));
                }}),

        buyConfirmGuiFillItemEnabled("buy.confirm.gui.fillItem.enabled", true, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can set if a fillitem should be used in the Confirm GUI."));
                }}),

        buyConfirmGuiFillItem("buy.confirm.gui.fillItem.material", T2C_ItemVersion.getBlackStainedGlassPane().getType().toString(), true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can set which fillitem should be used in the Confirm GUI."));
                }}),

        buyConfirmGuiConfirm("buy.confirm.gui.confirm.material", T2C_ItemVersion.getGreenWool().getType().toString(), true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can set the material for the confirmation button."));
                }}),

        buyConfirmGuiCancel("buy.confirm.gui.cancel.material", T2C_ItemVersion.getRedWool().getType().toString(), true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can set the material for the cancel button."));
                }}),

        subAliasTab("subAlias.tabComplete", true, true,
                new HashMap<>() {{
                    put(T2C_LanguageEnum.german, List.of());
                    put(T2C_LanguageEnum.english, List.of("Here you can set if subcommands should be displayed as tabComplete."));
                }}),
        ;

        private final String path;
        private Object value;
        private final boolean forceSet;
        private final HashMap<T2C_LanguageEnum, List<String>> comments;

        VALUES(String path, Object value, boolean forceSet, HashMap<T2C_LanguageEnum, List<String>> comments) {
            this.path = path;
            this.value = value;
            this.forceSet = forceSet;
            this.comments = comments;
        }

        @Override
        public String getPath() {
            return path;
        }

        @Override
        public Object getValue() {
            return value;
        }

        @Override
        public boolean getForceSet() {
            return forceSet;
        }

        @Override
        public HashMap<T2C_LanguageEnum, List<String>> getComments() {
            return comments;
        }

        @Override
        public String getLanguagePath() {
            return language.path;
        }

        @Override
        public void setValue(Object newValue) {
            value = newValue;
        }
    }

    public static void set(boolean isReload) {
        T2C_ConfigWriter.createConfig(Util.getPrefix(),new File(Main.getPath(), "config.yml"), VALUES.values(),isReload, Util.getConfigLogo());
    }

}
